from setuptools import setup

setup(name='tbtp',
      version='0.1',
      description='Thinact BackTest Platform',
      url='https://github.com/grantfang/tbtp',
      author='Grant Fang',
      author_email='grant.fang@thinact.com',
      license='MIT',
      packages=['tbtp'],
      zip_safe=False)